==> fyreonlib-0.2.4-sources.jar: com/vrs/android/fyreon/events/EventsBridge.java <==
/**---------------------------------------------------------------------------------
 File Name : EventsBridge.java
 Version Information : Version 1.1
 Date of Creation : 25/2/15
 Copyright Notice : This file is created by Virtual Reality Systems and all right reserve by VRS.
 -----------------------------------------------------------------------------------*/
package com.vrs.android.fyreon.events;

/**
 * ---------------------------------------------------------------------------------
 * Class Name : EventsBridge
 * Description : EventsBridge
 * Date of Creation : 25/2/15
 *
 * @author Virtual Reality systems
 *         <p/>
 *         -------------------------------------------------------------------------------------
 *         Update Log:
 *         Date:		By:		    Details:
 *         25/2/15    Rajan       Create full class
 *         24/3/15    Bhadresh    Refactor code as per coding standard.
 *         -----------------------------------------------------------------------------------
 */
public class EventsBridge {

    /**
     * ---------------------------------------------------------------------------------
     * Interface Name : onAnimationComplete
     * Description : Handle event when animation complete
     * Date of Creation : 25/2/15
     * <p/>
     * -------------------------------------------------------------------------------------
     * Update Log:
     * Date:		By:		    Details:
     * 25/2/15    Rajan       Create full class
     * 24/3/15    Bhadresh    Refactor code as per coding standard.
     * -----------------------------------------------------------------------------------
     */
    static public interface onAnimationComplete {

        public void onAnimationCompleteListener();
    }
}

==> fyreonlib-1.0.0-sources.jar: com/vrs/android/fyreon/events/EventsBridge.java <==
/**
 * ---------------------------------------------------------------------------------
 * File Name : EventsBridge.java
 * Version Information : Version 1.1
 * Date of Creation : 25/2/15
 * Copyright Notice : This file is created by Virtual Reality Systems and all right reserve by VRS.
 * -----------------------------------------------------------------------------------
 */
package com.vrs.android.fyreon.events;

/**
 * ---------------------------------------------------------------------------------
 * Class Name : EventsBridge
 * Description : EventsBridge
 * Date of Creation : 25/2/15
 *
 * @author Virtual Reality systems
 *         <p/>
 *         -------------------------------------------------------------------------------------
 *         Update Log:
 *         Date:		By:		    Details:
 *         25/2/15    Rajan       Create full class
 *         24/3/15    Bhadresh    Refactor code as per coding standard.
 *         -----------------------------------------------------------------------------------
 */
public class EventsBridge {

    /**
     * ---------------------------------------------------------------------------------
     * Interface Name : onAnimationComplete
     * Description : Handle event when animation complete
     * Date of Creation : 25/2/15
     * <p/>
     * -------------------------------------------------------------------------------------
     * Update Log:
     * Date:		By:		    Details:
     * 25/2/15    Rajan       Create full class
     * 24/3/15    Bhadresh    Refactor code as per coding standard.
     * -----------------------------------------------------------------------------------
     */
    public interface onAnimationComplete {
        void onAnimationCompleteListener();
    }
}
